@@ -2,14 +2,13 @@ from __future__ import with_statement
 import os
 import posixpath
 import pprint
+from copy import deepcopy
 from re import match
 from functools import wraps
-from fabric.api import *
+from fabric.api import env, prefix, cd, abort, warn, puts, run
 from fabric.contrib import files
-from fabric.utils import puts
 from fabric import state
 from fabric import network
-from fabric import operations
 
 
 __all__ = ['run_as', 'update_env', 'inside_project', 'inside_virtualenv',
@@ -99,7 +98,7 @@ def upload_config_template(name, to=None, skip_unexistent=False, **kwargs):
     if config_template is None:
         if skip_unexistent:
             return
-        operations._handle_failure('Config template "%s" is not found' % name)
+        abort('Config template "%s" is not found' % name)
 
     files.upload_template(config_template, to, env.conf, use_jinja=True,
                           **kwargs)
@@ -186,7 +185,7 @@ def update_env():
         if env.conf.VCS == vcs:
             env.conf.VCS = 'fab_deploy.vcs.' + vcs
 
-def define_host(host_string):
+def define_host(host_string, defaults=None):
     """
     This decorator populates :attr:`env.hosts`, :attr:`env.conf` and
     calls :func:`update_env() <fab_deploy.utils.update_env>`::
@@ -202,13 +201,18 @@ def define_host(host_string):
 
     Decorated function should return a dict with desired :attr:`env.conf`
     values.
-
     """
     def decorator(func):
         @wraps(func)
         def inner(*args, **kwargs):
             env.hosts = [host_string]
-            env.conf = func(*args, **kwargs)
+
+            if defaults is None:
+                env.conf = dict()
+            else:
+                env.conf = deepcopy(defaults)
+            env.conf.update(func(*args, **kwargs))
+
             update_env()
         return inner
     return decorator
