@@ -28,11 +28,18 @@ def pip_update(what=None, options='', restart=True):
     if restart:
         apache.touch()
 
-def pip_setup_conf():
+def pip_setup_conf(username=None):
     """ Sets up pip.conf file """
-    run('mkdir -p .pip')
-    utils.upload_config_template('pip.conf',
-        env.conf.HOME_DIR + '/.pip/pip.conf', skip_unexistent=True)
+    username = username or env.conf.USER
+    home_dir = utils.get_home_dir(username)
+
+    @utils.run_as(username)
+    def do_setup_conf():
+        run('mkdir --parents %s.pip' % home_dir)
+        utils.upload_config_template('pip.conf',
+            home_dir + '.pip/pip.conf', skip_unexistent=True)
+
+    do_setup_conf()
 
 def virtualenv_create():
     run('mkdir -p envs')
