@@ -12,19 +12,20 @@ from .base import FabDeployTest
 from ..utils import setup_ssh, setup_sudo
 from ..test_project.fabfile import foo_site, bar_site, invalid_site
 from ..test_project2.fabfile import foo_site as foo_site2
+from ..test_project3.fabfile import baz_site
 
 def get_file_content(remote_file):
     @run_as('root')
     def cat():
         with(hide('stdout')):
             return run('cat '+remote_file)
-    return fab(cat)[0]
+    return fab(cat)
 
 def get_ports():
     @run_as('root')
     def ports():
         return run('netstat -A inet -lnp')
-    return fab(ports)[0]
+    return fab(ports)
 
 def is_local_port_binded(port):
     port_string = '127.0.0.1:%s' % port
@@ -53,11 +54,11 @@ class FabDeployProjectTest(FabDeployTest):
 
     def assertCommandAvailable(self, command):
         result = fab(command_is_available, command)
-        self.assertTrue(result[0])
+        self.assertTrue(result)
 
     def assertCommandNotAvailable(self, command):
         result = fab(command_is_available, command)
-        self.assertFalse(result[0])
+        self.assertFalse(result)
 
     def assertCommandFails(self, command):
         self.assertRaises(FabricAbortException, fab,
@@ -207,3 +208,16 @@ class CustomLayoutDeployTest(FabDeployProjectTest):
         fab(deploy_project)
         fab(my_push)
         self.assertTrue(before_restart.called)
+
+
+class Django14LayoutDeployTest(FabDeployProjectTest):
+    project = 'test_project3'
+
+    def test_deploy(self):
+        url = 'http://baz.example.com/instance/'
+        fab(baz_site)
+
+        setup_sudo()
+        setup_ssh()
+        fab(deploy_project)
+        self.assertResponse(url, 'baz')
